@@ -1,5 +1,5 @@
 package Net::Silverpeak::Orchestrator;
-$Net::Silverpeak::Orchestrator::VERSION = '0.009000';
+$Net::Silverpeak::Orchestrator::VERSION = '0.010000';
 # ABSTRACT: Silverpeak Orchestrator REST API client library
 
 use 5.024;
@@ -189,6 +189,14 @@ sub has_segmentation_enabled ($self) {
 }
 
 
+sub get_vrf_zones_map ($self) {
+    my $res = $self->get("/gms/rest/zones/vrfZonesMap");
+    $self->_error_handler($res)
+        unless $res->code == 200;
+    return $res->data;
+}
+
+
 sub get_vrf_by_id ($self) {
     my $res = $self->get("/gms/rest/vrf/config/segments");
     $self->_error_handler($res)
@@ -476,7 +484,7 @@ Net::Silverpeak::Orchestrator - Silverpeak Orchestrator REST API client library
 
 =head1 VERSION
 
-version 0.009000
+version 0.010000
 
 =head1 SYNOPSIS
 
@@ -572,6 +580,10 @@ Throws an exception on error.
 
 Returns true if segmentation is enabled, else false.
 
+=head2 get_vrf_zones_map
+
+Returns a hashref of firewall zones indexed by VRF id and firewall zone id.
+
 =head2 get_vrf_by_id
 
 Returns a hashref of VRFs indexed by their id.
